@@ -19,6 +19,23 @@ class BrowserVulnerability:
             return data
         return False
 
+    @classmethod
+    def check_version(cls, criteria, version):
+        parsed = parse_version(version)
+        if "version__smaller" in criteria:
+            vp = parse_version(criteria.get("version__smaller"))
+            if parsed >= vp:
+                return False
+        if "version__larger" in criteria:
+            vp = parse_version(criteria.get("version__larger"))
+            if parsed < vp:
+                return False
+        if "version__extra" in criteria:
+            vp = criteria.get("version__extra")
+            if vp.match(version) is None:
+                return False
+        return True
+
     def check_os(self):
         if "flavor" not in self.parsed_ua and "platform" not in self.parsed_ua:
             return False
@@ -37,18 +54,10 @@ class BrowserVulnerability:
                 return
 
             tname = os.get("name")
-            tv = os.get("version__smaller")
-            tv_extra = os.get("version__extra")
-
             if os[a] == cname:
-                cversion = parse_version(cv)
-                tversion = parse_version(tv)
-                if cversion is not None and cversion < tversion:
-                    if tv_extra:
-                        if tv_extra.match(cv):
-                            return os
-                    else:
-                        return os
+                version_check = self.check_version(os, cv)
+                if version_check:
+                    return os
 
 
     def check_browser(self):
@@ -59,12 +68,14 @@ class BrowserVulnerability:
         for tbrowser in BROWSER:
             if tbrowser.get("name") != browser.get("name"):
                 continue
-            tversion = parse_version(tbrowser.get("version__smaller"))
-            if browser.get("version") is not None and parsed_version < tversion:
+            version_check = self.check_version(tbrowser, browser.get("version", ""))
+            if version_check:
                 return tbrowser
 
 def main():
     uas = [
+           'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36',
+           'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36',
            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/33.0.1750.146 Safari/537.36',
            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_2) AppleWebKit/537.74.9 (KHTML, like Gecko) Version/7.0.2 Safari/537.74.9',
            'Mozilla/5.0 (Windows NT 6.3; WOW64; rv:27.0) Gecko/20100101 Firefox/27.0',
@@ -72,9 +83,12 @@ def main():
            'Mozilla/5.0 (Windows NT 6.3; WOW64; rv:25.0) Gecko/20100101 Firefox/25.0',
            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.8; rv:27.0) Gecko/20100101 Firefox/27.0',
            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:27.0) Gecko/20100101 Firefox/27.0',
+           'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:27.0) Gecko/20100101 Firefox/27.0',
           ]
     for ua in uas:
         b = BrowserVulnerability(ua)
+        print 
+        print ua
         print b.vulnerabilities()
 
 if __name__ == '__main__':
